public inbox for libstdc++-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r12-6589] libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test
@ 2022-01-14 15:22 Uros Bizjak
  0 siblings, 0 replies; only message in thread
From: Uros Bizjak @ 2022-01-14 15:22 UTC (permalink / raw)
  To: gcc-cvs, libstdc++-cvs

https://gcc.gnu.org/g:6795e6ae66096d52a62e20ed33a47599233ab3d5

commit r12-6589-g6795e6ae66096d52a62e20ed33a47599233ab3d5
Author: Uros Bizjak <ubizjak@gmail.com>
Date:   Fri Jan 14 16:21:02 2022 +0100

    libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test
    
    The test fails on Fedora 33+ because nl_NL locale got thousands
    separator defined.  Use one of ar_SA, bg_BG, bs_BA, pt_PT
    or plain C locale instead.
    
    2022-01-14  Uroš Bizjak  <ubizjak@gmail.com>
    
    libstdc++-v3/ChangeLog:
    
            * testsuite/22_locale/numpunct/members/char/3.cc:
            Require pt_PT locale instead of nl_NL.
            (test02): Use pt_PT locale instead of nl_NL.

Diff:
---
 libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc b/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc
index 6e4959860cd..19b65d36e88 100644
--- a/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc
+++ b/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc
@@ -1,4 +1,4 @@
-// { dg-require-namedlocale "nl_NL.ISO8859-15" }
+// { dg-require-namedlocale "pt_PT.ISO8859-15" }
 
 // 2001-01-24 Benjamin Kosnik  <bkoz@redhat.com>
 
@@ -28,8 +28,8 @@ void test02()
 {
   using namespace std;
 
-  // nl_NL chosen because it has no thousands separator (at this time).
-  locale loc_it = locale(ISO_8859(15,nl_NL));
+  // pt_PT chosen because it has no thousands separator (at this time).
+  locale loc_it = locale(ISO_8859(15,pt_PT));
 
   const numpunct<char>& nump_it = use_facet<numpunct<char> >(loc_it);


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-01-14 15:22 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-01-14 15:22 [gcc r12-6589] libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test Uros Bizjak

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).